stafftools
==========

.. automodule:: abjad.tools.stafftools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff
      ~abjad.tools.stafftools.Staff.Staff.Staff

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.stafftools.make_rhythmic_sketch_staff.make_rhythmic_sketch_staff
